Page 114 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 114

Home

    Poinsett (1825-1829), was involved in the spread of
    Illuminist lodges into Mexico. Together, these Illuminist
    controlled lodges built an occult political machine out of
    which came the "liberal" leaders that used the power of

    government to wage war on religion.

    In 1827, a four-point program for this purpose was
    adopted in secret sessions in New Orleans by Poinsett
    and his pro-American liberal party. This platform
    eventually became law in Mexico and led to the absolute

    freedom of an anti-Christian press and speech, and
    absolute suppression of all others. It also led to the
    elimination of most of the monks and monasteries,

    Christian teachers and clergy, and the confiscation of all
    Christian schools, and institutions. As i in the ‘French

    Revolution, the battle cry was "liberty and equality."
    According to Michael Kenny, the author of No God
    Next Door, the Juarez code (1858-1871) formed the
    basis of a constitution that legalized the destruction of
    the Church that followed in the 20th century. Kenny

    The Juarez laws abolished all religious orders and
    confraternities, dress, vows, teachers, and teaching, with
    practically all civil rights and legal personality; nullified
    Christian marriages, and penalized religious rites and
    insignia anywhere outside the Church walls. Churches
    and all religious institutions were declared the property

    109

    Babylon's War Against God

    The first United States Minister to Mexico, Joel R.

    wrote that: